@@ -10,6 +10,7 @@ BLOCK_END = "block_end"
 CHAR = "char"
 KEYWORD = "keyword"
 IMPORT = "import"
+PRAGMA = "pragma"
 
 
 class LexerError(Exception):
@@ -38,7 +39,8 @@ class Lexer(object):
             Tokenizer(STRING, re.compile(r'("([^\\"]|(\\.))*")')),
             Tokenizer(BLOCK_START, re.compile("{")),
             Tokenizer(BLOCK_END, re.compile("}")),
-            Tokenizer(IMPORT, re.compile("^import .*$", re.MULTILINE)),
+            Tokenizer(IMPORT, re.compile("^import\s+.*$", re.MULTILINE)),
+            Tokenizer(PRAGMA, re.compile("^pragma\s+\w.*$", re.MULTILINE)),
             Tokenizer(KEYWORD, re.compile("(default\s+property|property|readonly\s+property|signal)\s+")),
             Tokenizer(KEYWORD, re.compile("(function)\s+[^(]")),  # a named function
             Tokenizer(ELEMENT, re.compile(r"\w[\w.<>]*")),
