@@ -1,6 +1,6 @@
-import lexer
+from . import lexer
 
-from qmlclass import QmlArgument, QmlProperty, QmlFunction, QmlSignal
+from .qmlclass import QmlArgument, QmlProperty, QmlFunction, QmlSignal
 
 
 class QmlParserError(Exception):
@@ -133,13 +133,23 @@ def parse_header(reader, cls):
         if token.type == lexer.COMMENT:
             cls.add_header_comment(token.value)
         elif token.type == lexer.IMPORT:
-            pass
+            cls.add_import(token.value)
+        elif token.type == lexer.PRAGMA:
+            cls.add_pragma(token.value)
         elif token.type == lexer.ELEMENT:
             cls.base_name = token.value
             return
         else:
             raise QmlParserUnexpectedTokenError(token)
 
+def parse_footer(reader, cls):
+    while not reader.at_end():
+        token = reader.consume()
+        if token.type == lexer.COMMENT:
+            cls.add_footer_comment(token.value)
+        else:
+            raise QmlParserUnexpectedTokenError(token)
+
 
 class TokenReader(object):
     def __init__(self, tokens):
@@ -173,3 +183,4 @@ def parse(tokens, cls):
     reader = TokenReader(tokens)
     parse_header(reader, cls)
     parse_class_definition(reader, cls)
+    parse_footer(reader, cls)
